==> haskell-xdg-basedir-0.2.2-10-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-basedir.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xdg-basedir
version:              0.2.2
visibility:           public
id:                   xdg-basedir-0.2.2-HxO6vm11dHzJE1a7l4Y8Vh
key:                  xdg-basedir-0.2.2-HxO6vm11dHzJE1a7l4Y8Vh
license:              BSD-3-Clause
copyright:            (c) 2011 Will Donnelly
maintainer:           Will Donnelly <will.donnelly@gmail.com>
author:               Will Donnelly
stability:            alpha
homepage:             http://github.com/willdonnelly/xdg-basedir
synopsis:
    A basic implementation of the XDG Base Directory specification.

description:
    On Unix platforms, this should be a very straightforward
    implementation of the XDG Base Directory spec. On Windows,
    it will attempt to do the right thing with regards to
    choosing appropriate directories.

category:             System
abi:                  65f35d3b9c62c98b06c700178e6d03cd
exposed:              True
exposed-modules:      System.Environment.XDG.BaseDir
import-dirs:          /usr/lib/ghc-8.10.5/site-local/xdg-basedir-0.2.2
library-dirs:         /usr/lib/ghc-8.10.5/site-local/xdg-basedir-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.5/xdg-basedir-0.2.2
hs-libraries:         HSxdg-basedir-0.2.2-HxO6vm11dHzJE1a7l4Y8Vh
depends:              base-4.14.2.0 directory-1.3.6.0 filepath-1.4.2.1
haddock-interfaces:   /usr/share/doc/haskell-xdg-basedir/html/xdg-basedir.haddock
haddock-html:         /usr/share/doc/haskell-xdg-basedir/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xdg-basedir-0.2.2-11-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xdg-basedir.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xdg-basedir
version:              0.2.2
visibility:           public
id:                   xdg-basedir-0.2.2-FxvLd0PtCIDHWciCXDjKP6
key:                  xdg-basedir-0.2.2-FxvLd0PtCIDHWciCXDjKP6
license:              BSD-3-Clause
copyright:            (c) 2011 Will Donnelly
maintainer:           Will Donnelly <will.donnelly@gmail.com>
author:               Will Donnelly
stability:            alpha
homepage:             http://github.com/willdonnelly/xdg-basedir
synopsis:
    A basic implementation of the XDG Base Directory specification.

description:
    On Unix platforms, this should be a very straightforward
    implementation of the XDG Base Directory spec. On Windows,
    it will attempt to do the right thing with regards to
    choosing appropriate directories.

category:             System
abi:                  34109ebe0124855568740e38eafb740c
exposed:              True
exposed-modules:      System.Environment.XDG.BaseDir
import-dirs:          /usr/lib/ghc-9.0.1/site-local/xdg-basedir-0.2.2
library-dirs:         /usr/lib/ghc-9.0.1/site-local/xdg-basedir-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-9.0.1/xdg-basedir-0.2.2
hs-libraries:         HSxdg-basedir-0.2.2-FxvLd0PtCIDHWciCXDjKP6
depends:              base-4.15.0.0 directory-1.3.6.1 filepath-1.4.2.1
haddock-interfaces:   /usr/share/doc/haskell-xdg-basedir/html/xdg-basedir.haddock
haddock-html:         /usr/share/doc/haskell-xdg-basedir/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
